---
obj: concept
wiki: https://en.wikipedia.org/wiki/Game_theory
rev: 2024-05-29
---

# Game Theory
Game theory is a mathematical framework designed for analyzing competitive situations where the outcomes depend on the actions of multiple agents, each with their own interests. It is widely used in economics, political science, [psychology](../../psychology/Psychology.md), [biology](../../biology/Biology.md), and computer science to model and study interactions among rational decision-makers.

## Key Concept

### Players
Players are the decision-makers in a game. Each player aims to maximize their own payoff, which depends on the strategies chosen by all players.

### Strategies
A strategy is a complete plan of action a player will follow in a game, given the possible situations they might face. Strategies can be pure (deterministic) or mixed (probabilistic).

### Payoffs
Payoffs are the rewards or outcomes that players receive as a result of the strategies they choose. Payoffs are often represented in a matrix form in simpler games.

### Games
Games can be classified based on various criteria:
- **Cooperative vs. Non-Cooperative:** In cooperative games, players can form binding commitments, while in non-cooperative games, they cannot.
- **Symmetric vs. Asymmetric:** In symmetric games, the payoffs depend only on the strategies employed, not on who is playing. In asymmetric games, the identities of the players matter.
- **Zero-Sum vs. Non-Zero-Sum:** In zero-sum games, one player's gain is another player's loss. In non-zero-sum games, the total payoff can vary, allowing for win-win situations.

## Types of Games

### Simultaneous-Move Games
In simultaneous-move games, players choose their strategies without knowing the choices of the other players. A common representation is the payoff matrix. An example is the Prisoner's Dilemma.

#### Prisoner's Dilemma
The Prisoner's Dilemma is a standard example in game theory. Two prisoners must decide whether to confess or remain silent without knowing the other's decision. The optimal strategy leads both to confess, resulting in a worse outcome for both.

|                             | Prisoner B Stays Silent | Prisoner B Confesses |
| --------------------------- | ----------------------- | -------------------- |
| **Prisoner A Stays Silent** | A: -1, B: -1            | A: -10, B: 0         |
| **Prisoner A Confesses**    | A: 0, B: -10            | A: -5, B: -5         |

### Sequential-Move Games
In sequential-move games, players make decisions one after another, with each player observing the previous actions before making their choice. These games are often represented by game trees.

#### Example: Chess
Chess is a classic example of a sequential-move game where players take turns making moves, and each player's strategy depends on the previous moves made by the opponent.

### Repeated Games
Repeated games occur when players engage in the same game multiple times. Strategies can evolve over time, and cooperation can emerge even in non-cooperative settings.

#### Example: Iterated Prisoner's Dilemma
In the Iterated Prisoner's Dilemma, players play the Prisoner's Dilemma multiple times, allowing for strategies like "tit for tat," where a player reciprocates the opponent's previous action.

### Evolutionary Game Theory
Evolutionary game theory studies how strategies evolve over time, often using concepts from [biology](../../biology/Biology.md). It focuses on populations of players who may adopt different strategies based on their success.

#### Example: Hawk-Dove Game
The Hawk-Dove game models the behavior of animals in conflict over resources. Hawks are aggressive, while Doves are peaceful. The game's outcomes depend on the costs and benefits of fighting versus sharing.

## Nash Equilibrium
A Nash Equilibrium is a set of strategies where no player can benefit by unilaterally changing their strategy, given the strategies of the other players. It represents a state of mutual best responses.

### Example: Battle of the Sexes
In the Battle of the Sexes, two players (typically representing a couple) prefer different activities but want to do something together. Multiple Nash Equilibria exist, where each player's best response depends on the other's choice.

|                        | Player B: Opera | Player B: Football |
| ---------------------- | --------------- | ------------------ |
| **Player A: Opera**    | A: 2, B: 1      | A: 0, B: 0         |
| **Player A: Football** | A: 0, B: 0      | A: 1, B: 2         |

## Applications of Game Theory
Game theory has applications across various fields:
- **Economics:** Market competition, auctions, and bargaining.
- **Political Science:** Voting systems, coalition formation, and international relations.
- **[Biology](../../biology/Biology.md):** Evolution of cooperation, animal behavior, and population dynamics.
- **Computer Science:** Algorithm design, network security, and artificial intelligence.
