# Ohm's Law
Ohm's Law is a fundamental principle in electrical engineering and physics that describes the relationship between voltage, current, and resistance in an electrical circuit. It is named after the German physicist Georg Simon Ohm, who first formulated it in 1827.

## The Formula
Ohm's Law is typically represented by the equation:

$U = R * I$

Where:
- $U$ is the voltage across the conductor (measured in [volt](units/Volt.md), V).
- $R$ is the resistance of the conductor (measured in ohm, Ω).
- $I$ is the current flowing through the conductor (measured in [ampere](units/Ampere.md), A).

## Understanding the Components

### Voltage (V)
Voltage is the electrical potential difference between two points in a circuit. It represents the "push" or force that drives electric charge through a conductor. Voltage is measured in volts (V) and is typically provided by a power source such as a battery or an electrical outlet.

### Current (I)
Current is the flow of electric charge through a conductor over time. It represents the rate at which electric charge passes through a given point in a circuit. Current is measured in amperes (A) and is typically denoted as the amount of charge passing through a point per unit of time.

### Resistance (R)
Resistance is a property of a material that opposes the flow of electric current. It determines how much current will flow through a circuit for a given voltage. Resistance is measured in ohms (Ω) and depends on factors such as the material of the conductor, its length, cross-sectional area, and temperature.

## Applications of Ohm's Law

### Calculating Unknown Values
Ohm's Law can be used to calculate any one of the three variables (voltage, current, or resistance) if the other two are known. This makes it an invaluable tool in designing and analyzing electrical circuits.

### Circuit Analysis
Ohm's Law is fundamental to circuit analysis and is used extensively in determining the behavior of various components within a circuit. By applying Ohm's Law along with other circuit laws and principles, engineers can predict voltages, currents, and power dissipation in complex circuits.

### Electrical Safety
Understanding Ohm's Law is essential for ensuring electrical safety. By knowing the relationship between voltage, current, and resistance, engineers and technicians can design circuits with appropriate safety measures and calculate values to prevent overloading components or causing hazardous conditions.

## Circuit Laws
### Kirchhoff's Laws
#### Kirchhoff's Voltage Law (KVL)
Kirchhoff's Voltage Law states that the total voltage around any closed loop in a circuit is equal to the sum of the voltage drops within that loop.

$ΣV = 0$

Where:
- ΣV is the sum of voltages in a closed loop.

#### Kirchhoff's Current Law (KCL)
Kirchhoff's Current Law states that the total current entering a junction (or node) in a circuit is equal to the total current leaving the junction. Mathematically, it can be expressed as:

$ΣI = 0$

Where:
- ΣI is the sum of currents at a junction.

### Behavior of Voltage in Circuits
#### Series Circuits
In a series circuit, components are connected end-to-end, forming a single pathway for current flow. The voltage across each component adds up to the total voltage of the circuit. Mathematically, for n components in series:

$V_{total} = V_1 + V_2 + ... + V_n$

Where:
- $V_{total}$ is the total voltage across the series circuit.
- $V_1$, $V_2$, ..., $V_n$ are the voltages across each component.

#### Parallel Circuits
In a parallel circuit, components are connected across common points, forming multiple pathways for current flow. The voltage across each component in a parallel circuit is the same, as they are all connected directly across the voltage source. Mathematically, the voltage across each component is equal to the total voltage of the circuit:

$V_1 = V_2 = ... = V_n = V_{total}$

Where:
- $V_1$, $V_2$, ..., $V_n$ are the voltages across each component.
- $V_{total}$ is the total voltage across the parallel circuit.
