---
obj: application
arch-wiki: https://wiki.archlinux.org/title/SDDM
wiki: https://en.wikipedia.org/wiki/Simple_Desktop_Display_Manager
repo: https://github.com/sddm/sddm
rev: 2024-12-18
---

# SDDM
The Simple Desktop Display Manager (SDDM) is a display manager. It is the recommended display manager for the KDE Plasma and LXQt desktop environments. 

## Configuration
The default configuration file for SDDM can be found at `/usr/lib/sddm/sddm.conf.d/default.conf`. For any changes, create configuration file(s) in `/etc/sddm.conf.d/`.

Everything should work out of the box, since Arch Linux uses systemd and SDDM defaults to using `systemd-logind` for session management.

### Autologin
SDDM supports automatic login through its configuration file, for example (`/etc/sddm.conf.d/autologin.conf`):

```ini
[Autologin]
User=john
Session=plasma

# Optionally always relogin the user on logout
Relogin=true
```

This configuration causes a KDE Plasma session to be started for user `john` when the system is booted. Available session types can be found in `/usr/share/xsessions/` for X and in `/usr/share/wayland-sessions/` for Wayland.

To autologin into KDE Plasma while simultaneously locking the session (e.g. to allow autostarted apps to warm up), create a systemd user unit drop in to pass `--lockscreen` in `plasma-ksmserver.service` (`~/.config/systemd/user/plasma-ksmserver.service.d/override.conf`):

```ini
[Service]
ExecStart=
ExecStart=/usr/bin/ksmserver --lockscreen
```

### Theme settings
Theme settings can be changed in the `[Theme]` section. If you use Plasma's system settings, themes may show previews.

Set to `breeze` for the default Plasma theme.

#### Current theme

Set the current theme through the Current value, e.g. `Current=archlinux-simplyblack`.

#### Editing themes
The default SDDM theme directory is `/usr/share/sddm/themes/`. You can add your custom made themes to that directory under a separate subdirectory. Note that SDDM requires these subdirectory names to be the same as the theme names. Study the files installed to modify or create your own theme.

#### Customizing a theme
To override settings in the `theme.conf` configuration file, create a custom `theme.conf.user` file in the same directory. For example, to change the theme's background (`/usr/share/sddm/themes/name/theme.conf.user`):

```ini
[General]
background=/path/to/background.png
```

#### Testing (previewing) a theme
You can preview an SDDM theme if needed. This is especially helpful if you are not sure how the theme would look if selected or just edited a theme and want to see how it would look without logging out. You can run something like this:

```sh
sddm-greeter-qt6 --test-mode --theme /usr/share/sddm/themes/breeze
```

This should open a new window for every monitor you have connected and show a preview of the theme.

#### Mouse cursor
To set the mouse cursor theme, set `CursorTheme` to your preferred cursor theme.

Valid Plasma mouse cursor theme names are `breeze_cursors`, `Breeze_Snow` and `breeze-dark`. 

### Keyboard Layout
To set the keyboard layout with SDDM, edit ` /usr/share/sddm/scripts/Xsetup`:

```
#!/bin/sh
# Xsetup - run as root before the login dialog appears
setxkbmap de,us
```
