---
obj: application
website: https://docs.renovatebot.com
repo: https://github.com/renovatebot/renovate
---

# RenovateBot

RenovateBot is a powerful open-source tool that automates the process of updating dependencies in your codebase. It scans your project files, identifies outdated packages, and creates pull requests to update them—keeping your dependencies secure and up to date with minimal manual intervention.

## Setup
Setup a user for renovate on your preferred git forge and get a PAT to authenticate.

Then add this user as a member to your repositories. Renovate can then be configured through a `renovate.json` config file per repository.

## K8s Manifest
```yml
apiVersion: batch/v1
kind: CronJob
metadata:
  name: renovate
spec:
  schedule: '@hourly'
  concurrencyPolicy: Forbid
  jobTemplate:
    spec:
      template:
        spec:
          containers:
            - name: renovate
              # Update this to the latest available and then enable Renovate on
              # the manifest
              image: renovate/renovate:40.57.0
              args:
                - user/repo
              # Environment Variables
              env:
                - name: LOG_LEVEL
                  value: debug
              envFrom:
                - secretRef:
                    name: renovate-env
          restartPolicy: Never
---
apiVersion: v1
kind: Secret
metadata:
  name: renovate-env
type: Opaque
stringData:
  RENOVATE_GITHUB_COM_TOKEN: 'any-personal-user-token-for-github-com-for-fetching-changelogs'
  # You can set RENOVATE_AUTODISCOVER to true to run Renovate on all repos you have push access to
  RENOVATE_AUTODISCOVER: 'false'
  RENOVATE_ENDPOINT: 'https://github.company.com/api/v3'
  RENOVATE_GIT_AUTHOR: 'Renovate Bot <bot@renovateapp.com>'
  RENOVATE_PLATFORM: 'github'
  RENOVATE_TOKEN: 'your-github-enterprise-renovate-user-token'
```
