---
obj: application
website: https://valkey.io
repo: https://github.com/valkey-io/valkey
---

# Valkey

**Valkey** is a high-performance, in-memory key-value data store and cache that is fully open source and community-driven. It is a hard fork of Redis, created and maintained by the open-source community after concerns arose about Redis' license change (from BSD to SSPL).

Valkey maintains full compatibility with Redis as of version 7.2 and continues to support core Redis features such as data structures, replication, persistence, clustering, and Lua scripting. Its primary goal is to offer a drop-in replacement with a transparent development process, ensuring long-term freedom and reliability for developers and organizations.

## Key Features

- ⚡ **In-Memory Speed**: Extremely fast data access due to in-memory storage.
- 🧱 **Rich Data Structures**: Strings, Lists, Sets, Sorted Sets, Hashes, Bitmaps, HyperLogLogs, Streams.
- 📜 **Lua Scripting**: Supports server-side scripting with Lua for atomic operations.
- 🧩 **Modules Support**: Supports Redis modules (as of 7.2 compatibility).
- 🔁 **Replication**: Built-in master-replica replication for high availability.
- 💾 **Persistence Options**: RDB snapshots and AOF (Append-Only File) for durability.
- 🔄 **Pub/Sub Messaging**: Lightweight publish/subscribe mechanism for message broadcasting.
- 📡 **Clustering**: Built-in support for sharded cluster mode.

## Compose

```yaml
version: '3.8'

services:
  valkey:
    image: valkey/valkey:latest
    container_name: valkey
    ports:
      - "6379:6379"
    volumes:
      - ./valkey_data:/data
    restart: unless-stopped
    command: valkey-server --appendonly yes
```
