---
obj: application
website: https://sftpgo.com
repo: https://github.com/drakkan/sftpgo
source: https://docs.sftpgo.com/latest
---

# SFTPGo
SFTPGo is an event-driven file transfer solution. It support multiple protocols (SFTP, SCP, FTP/S, WebDAV, HTTP/S) and multiple storage backends.
With SFTPGo you can leverage local and cloud storage backends for exchanging and storing files internally or with business partners using the same tools and processes you are already familiar with.
The WebAdmin UI allows to easily create and manage your users, folders, groups and other resources.

## Features
- Support for serving local filesystem, encrypted local filesystem, S3 Compatible Object Storage, Google Cloud Storage, Azure Blob Storage or other SFTP accounts over SFTP/SCP/FTP/WebDAV.
- Virtual folders are supported: a virtual folder can use any of the supported storage backends. So you can have, for example, a user with the S3 backend mapping a GCS bucket (or part of it) on a specified path and an encrypted local filesystem on another one. Virtual folders can be private or shared among multiple users, for shared virtual folders you can define different quota limits for each user.
- Configurable custom commands and/or HTTP hooks on upload, pre-upload, download, pre-download, delete, pre-delete, rename, mkdir, rmdir on SSH commands and on user add, update and delete.
- Virtual accounts stored within a "data provider".
- SQLite, MySQL, PostgreSQL, CockroachDB, Bolt (key/value store in pure Go) and in-memory data providers are supported.
- Chroot isolation for local accounts. Cloud-based accounts can be restricted to a certain base path.
- Per-user and per-directory virtual permissions, for each path you can allow or deny: directory listing, upload, overwrite, download, delete, rename, create directories, create symlinks, change owner/group/file mode and modification time.
- REST API for users and folders management, data retention, backup, restore and real time reports of the active connections with possibility of forcibly closing a connection.
- The Event Manager allows to define custom workflows based on server events or schedules.
- Web based administration interface to easily manage users, folders and connections.
- Web client interface so that end users can change their credentials, manage and share their files in the browser.
- Public key and password authentication. Multiple public keys per-user are supported.
- SSH user certificate authentication.
- Keyboard interactive authentication. You can easily setup a customizable multi-factor authentication.
- Partial authentication. You can configure multi-step authentication requiring, for example, the user password after successful public key authentication.
- Per-user authentication methods.
- Two-factor authentication based on time-based one time passwords (RFC 6238) which works with Google Authenticator, Microsoft Authenticator, Authy and other compatible apps.
- LDAP/Active Directory authentication using a plugin.
- Simplified user administrations using groups.
- Roles allow to create limited administrators who can only create and manage users with their role.
- Custom authentication via external programs/HTTP API.
- Web Client and Web Admin user interfaces support OpenID Connect authentication and so they can be integrated with identity providers such as Keycloak. You can find more details here.
- Data At Rest Encryption.
- Dynamic user modification before login via external programs/HTTP API.
- Quota support: accounts can have individual disk quota expressed as max total size and/or max number of files.
- Bandwidth throttling, with separate settings for upload and download and overrides based on the client's IP address.
- Data transfer bandwidth limits, with total limit or separate settings for uploads and downloads and overrides based on the client's IP address. Limits can be reset using the REST API.
- Per-protocol rate limiting is supported and can be optionally connected to the built-in defender to automatically block hosts that repeatedly exceed the configured limit.
- Per-user maximum concurrent sessions.
- Per-user and global IP filters: login can be restricted to specific ranges of IP addresses or to a specific IP address.
- Per-user and per-directory shell like patterns filters: files can be allowed, denied and optionally hidden based on shell like patterns.
- Automatically terminating idle connections.
- Automatic blocklist management using the built-in defender.
- Geo-IP filtering using a plugin.
- Atomic uploads are configurable.
- Per-user files/folders ownership mapping: you can map all the users to the system account that runs SFTPGo (all platforms are supported) or you can run SFTPGo as root user and map each user or group of users to a different system account (*NIX only).
- Support for Git repositories over SSH.
- SCP and rsync are supported.
- FTP/S is supported. You can configure the FTP service to require TLS for both control and data connections.
WebDAV is supported.
- ACME protocol is supported. SFTPGo can obtain and automatically renew TLS certificates for HTTPS, WebDAV and FTPS from Let's Encrypt or other ACME compliant certificate authorities, using the HTTP-01 or TLS-ALPN-01 challenge types.
- Two-Way TLS authentication, aka TLS with client certificate authentication, is supported for REST API/Web Admin, FTPS and WebDAV over HTTPS.
- Per-user protocols restrictions. You can configure the allowed protocols (SSH/HTTP/FTP/WebDAV) for each user.
- Prometheus metrics are supported.
- Support for HAProxy PROXY protocol: you can proxy and/or load balance the SFTP/SCP/FTP service without losing the information about the client's address.
- Easy migration from Linux system user accounts.
- Portable mode: a convenient way to share a single directory on demand.
- SFTP subsystem mode: you can use SFTPGo as OpenSSH's SFTP subsystem.
- Performance analysis using built-in profiler.
- Configuration format is at your choice: JSON, TOML, YAML, envfile are supported.
- Log files are accurate and they are saved in the easily parsable JSON format (more information).
- SFTPGo supports a plugin system and therefore can be extended using external plugins.
- Infrastructure as Code (IaC) support using the Terraform provider.
- Partial (experimental) support for internationalization for WebAdmin and WebClient user interfaces.

## Compose
```yml
services:
    sftpgo:
        user: 1001:1001 # User
        ports:
            - 5927:5927 # Telemetry
            - 5929:5929 # WebDAV
            - 5928:8080 # HTTP UI
            - 2222:2022 # SFTP
        volumes:
            - "./data:/srv/sftpgo"
            - "./config:/var/lib/sftpgo"
        environment:
            # Telemetry
            - "SFTPGO_TELEMETRY__BIND_PORT=5927"
            - "SFTPGO_TELEMETRY__BIND_ADDRESS=0.0.0.0"
            # WebDAV
            - "SFTPGO_WEBDAVD__BINDINGS__0__PORT=5929"
            - "SFTPGO_WEBDAVD__BINDINGS__0__ADDRESS=0.0.0.0"
        image: drakkan/sftpgo:distroless-slim
```
