---
obj: application
rev: 2024-12-23
---

# systemd-detect-virt
systemd-detect-virt detects execution in a virtualized environment. It identifies the virtualization technology and can distinguish full machine virtualization from container virtualization. systemd-detect-virt exits with a return value of 0 (success) if a virtualization technology is detected, and non-zero (error) otherwise. By default, any type of virtualization is detected, and the options `--container` and `--vm` can be used to limit what types of virtualization are detected.

When executed without `--quiet` will print a short identifier for the detected virtualization technology. The following technologies are currently identified:

| **Type**  | **ID**           | **Product**                                                                                                                                                                     |
| --------- | ---------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| vm        | `qemu`           | QEMU software virtualization, without KVM                                                                                                                                       |
| vm        | `kvm`            | Linux KVM kernel virtual machine, in combination with QEMU. Not used for other virtualizers using the KVM interfaces, such as Oracle VirtualBox or Amazon EC2 Nitro, see below. |
| vm        | `amazon`         | Amazon EC2 Nitro using Linux KVM                                                                                                                                                |
| vm        | `zvm`            | s390 z/VM                                                                                                                                                                       |
| vm        | `vmware`         | VMware Workstation or Server, and related products                                                                                                                              |
| vm        | `microsoft`      | Hyper-V, also known as Viridian or Windows Server Virtualization                                                                                                                |
| vm        | `oracle`         | Oracle VM VirtualBox (historically marketed by innotek and Sun Microsystems), for legacy and KVM hypervisor                                                                     |
| vm        | `powervm`        | IBM PowerVM hypervisor — comes as firmware with some IBM POWER servers                                                                                                          |
| vm        | `xen`            | Xen hypervisor (only domU, not dom0)                                                                                                                                            |
| vm        | `bochs`          | Bochs Emulator                                                                                                                                                                  |
| vm        | `uml`            | User-mode Linux                                                                                                                                                                 |
| vm        | `parallels`      | Parallels Desktop, Parallels Server                                                                                                                                             |
| vm        | `bhyve`          | bhyve, FreeBSD hypervisor                                                                                                                                                       |
| vm        | `qnx`            | QNX hypervisor                                                                                                                                                                  |
| vm        | `acrn`           | ACRN hypervisor                                                                                                                                                                 |
| vm        | `apple`          | Apple virtualization framework                                                                                                                                                  |
| vm        | `sre`            | LMHS SRE hypervisor                                                                                                                                                             |
| vm        | `google`         | Google Compute Engine                                                                                                                                                           |
| container | `openvz`         | OpenVZ/Virtuozzo                                                                                                                                                                |
| container | `lxc`            | Linux container implementation by LXC                                                                                                                                           |
| container | `lxc-libvirt`    | Linux container implementation by libvirt                                                                                                                                       |
| container | `systemd-nspawn` | systemd's minimal container implementation, see systemd-nspawn(1) manual page                                                                                                   |
| container | `docker`         | Docker container manager                                                                                                                                                        |
| container | `podman`         | Podman container manager                                                                                                                                                        |
| container | `rkt`            | rkt app container runtime                                                                                                                                                       |
| container | `wsl`            | Windows Subsystem for Linux                                                                                                                                                     |
| container | `proot`          | proot userspace chroot/bind mount emulation                                                                                                                                     |
| container | `pouch`          | Pouch Container Engine                                                                                                                                                          |

If multiple virtualization solutions are used, only the "innermost" is detected and identified. That means if both machine and container virtualization are used in conjunction, only the latter will be identified (unless `--vm` is passed).

## Options

| Option            | Description                                                                                                                                                                          |
| ----------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| `-c, --container` | Only detects container virtualization (i.e. shared kernel virtualization).                                                                                                           |
| `-v, --vm`        | Only detects hardware virtualization.                                                                                                                                                |
| `-r, --chroot`    | Detect whether invoked in a chroot environment. In this mode, no output is written, but the return value indicates whether the process was invoked in a chroot() environment or not. |
| `-q, --quiet`     | Suppress output of the virtualization technology identifier.                                                                                                                         |
| `--list`          | Output all currently known and detectable container and VM environments.                                                                                                             |
